BORIS (Behavioral Observation Research Interactive Software)
===============================================================


![BORIS logo](https://github.com/olivierfriard/BORIS/blob/master/boris/icons/logo_boris.png?raw=true)

BORIS is an easy-to-use event logging software for video/audio coding or live observations.

BORIS is a free and open-source software available for GNU/Linux and Windows.
You can not longer run BORIS natively on MacOS (since v.8). Some alternatives to run the last version of BORIS are available, see [BORIS on MacOS](https://www.boris.unito.it/download_mac).

It provides also some analysis tools like time budget and some plotting functions.

The BORIS paper has more than [![BORIS citations counter](http://penelope.unito.it/friard/boris_scopus_citations.png) citations](https://www.boris.unito.it/citations) in peer-reviewed scientific publications.




See the official [BORIS web site](https://www.boris.unito.it).

[![Python web site](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)](https://www.python.org)
![Python versions](https://img.shields.io/pypi/pyversions/boris-behav-obs)
![BORIS license](https://img.shields.io/pypi/l/boris-behav-obs)
[![Number of downloads](https://static.pepy.tech/personalized-badge/boris-behav-obs?period=total&units=international_system&left_color=black&right_color=orange&left_text=Downloads)](https://pepy.tech/project/boris-behav-obs)
![commit-activity](https://img.shields.io/github/commit-activity/m/olivierfriard/BORIS)
[![PyPI version](https://img.shields.io/pypi/v/boris-behav-obs.svg)](https://pypi.org/project/boris-behav-obs/)
![BORIS scopus citations badge](http://penelope.unito.it/friard/boris_scopus_citations.svg)




# Documentation



The [user guide](https://www.boris.unito.it/user_guide/) provides a good starting point for learning how to use BORIS.

Some [video tutorials](https://www.boris.unito.it/video_tutorials/) are available.





# Bug reports and feature requests


To search for bugs, report them or request a feature, please use the github tracker:
https://github.com/olivierfriard/BORIS/issues





# Citing BORIS


Please acknowledge and cite the use of this software and its authors when
results are used in publications or published elsewhere. You can use the
following BibTex entry

```
@article {MEE3:MEE312584,
    author = {Friard, Olivier and Gamba, Marco},
   title = {BORIS: a free, versatile open-source event-logging software for video/audio coding and live observations},
   journal = {Methods in Ecology and Evolution},
   issn = {2041-210X},
   url = {http://dx.doi.org/10.1111/2041-210X.12584},
   doi = {10.1111/2041-210X.12584},
   pages = {1324--1330},
    year = {2016},
}
```

You can also send us a nice postcard! See the [user testimonials](https://www.boris.unito.it/postcards).








# Licence


This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.


Distributed with a [GPL v.3 license](LICENSE.TXT).

Copyright (C) 2012-2024 Olivier Friard




